﻿using Correo.MailKit;
using Correo.NetSmtpClient;
using Correo.SendGrid;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using System;

namespace Correo.Extensions
{
    public static class SmtpExtensions
    {
        public static void AddSmtpService(this IServiceCollection services, IConfiguration configuration)
        {
            var mediator = configuration.GetValue("SmtpMediator", ".NET");
            if (mediator.Equals(".NET", StringComparison.InvariantCultureIgnoreCase))
            {
                services.AddNetSmtpClient(configuration.GetSection("SmtpClient"));
            }
            else if (mediator.Equals("MailKit", StringComparison.InvariantCultureIgnoreCase))
            {
                services.AddMailKitSmtpClient(configuration.GetSection("SmtpClient"));
            }
            else if (mediator.Equals("SendGrid", StringComparison.InvariantCultureIgnoreCase))
            {
                services.AddSendGridService(configuration.GetSection("SmtpService"));
            }
            else
            {
                throw new NotImplementedException($"SmtpMediator '{mediator}' is not implemented.");
            }
        }
    }
}
